Per-pipeline SurrealDB table names.
Each sync pipeline gets its own set of tables for isolation,
named by a deterministic pattern: sync_{source}_{type}.
Structs
- Table
Names - Table names for a sync pipeline’s internal state.
Per-pipeline SurrealDB table names.
Each sync pipeline gets its own set of tables for isolation,
named by a deterministic pattern: sync_{source}_{type}.